Index: /branches/2.4/workflow/setup/default_records.inc.php
===================================================================
--- /branches/2.4/workflow/setup/default_records.inc.php	(revision 5726)
+++ /branches/2.4/workflow/setup/default_records.inc.php	(revision 6589)
@@ -85,5 +85,5 @@
 	$workflowDB->query('CREATE TABLE centro_custo (organizacao_id integer NOT NULL, centro_custo_id serial NOT NULL, nm_centro_custo integer NOT NULL, grupo character varying(30), descricao character varying(100) NOT NULL)');
 	$workflowDB->query('CREATE TABLE localidade (organizacao_id integer NOT NULL, localidade_id serial NOT NULL, centro_custo_id integer, descricao character varying(50) NOT NULL, empresa CHARACTER VARYING(100), endereco CHARACTER VARYING(100), complemento CHARACTER VARYING(50), cep CHARACTER VARYING(9), bairro CHARACTER VARYING(30), cidade CHARACTER VARYING(50), uf CHARACTER(2))');
-	$workflowDB->query('CREATE TABLE funcionario (funcionario_id int4 NOT NULL, area_id integer NOT NULL, localidade_id integer NOT NULL, centro_custo_id integer, organizacao_id integer NOT NULL, funcionario_status_id integer NOT NULL, cargo_id int4, nivel int2, funcionario_categoria_id int4, titulo CHARACTER VARYING(30))');
+	$workflowDB->query('CREATE TABLE funcionario (funcionario_id int4 NOT NULL, area_id integer NOT NULL, localidade_id integer NOT NULL, centro_custo_id integer, organizacao_id integer NOT NULL, funcionario_status_id integer NOT NULL, cargo_id int4, nivel int2, funcionario_categoria_id int4, titulo CHARACTER VARYING(30), funcao CHARACTER VARYING(200), data_admissao DATE, apelido CHARACTER VARYING(20))');
 	$workflowDB->query('CREATE TABLE area (organizacao_id integer NOT NULL, area_id serial NOT NULL, area_status_id integer NOT NULL, superior_area_id integer, centro_custo_id integer, titular_funcionario_id int4, sigla character varying(20) NOT NULL, descricao character varying(100) NOT NULL, ativa character varying(1) NOT NULL, auxiliar_funcionario_id int4)');
 	$workflowDB->query('CREATE TABLE funcionario_status (funcionario_status_id serial NOT NULL, descricao character varying(50) NOT NULL, exibir character varying(1) NOT NULL, organizacao_id integer NOT NULL)');
Index: /branches/2.4/workflow/setup/tables_update.inc.php
===================================================================
--- /branches/2.4/workflow/setup/tables_update.inc.php	(revision 5726)
+++ /branches/2.4/workflow/setup/tables_update.inc.php	(revision 6589)
@@ -326,7 +326,29 @@
 			}
 
-
+		/* reconnect to the previous database */
+		$GLOBALS['phpgw']->ADOdb->connect($workflowHostInfo['host'], $workflowHostInfo['user'], $workflowHostInfo['password'], $workflowHostInfo['dbname']);
 		$GLOBALS['setup_info']['workflow']['currentver'] = '2.4.0';
 		return $GLOBALS['setup_info']['workflow']['currentver'];
 	}
+	
+	$test[] = '2.4.0';	
+	function workflow_upgrade2_4_0()
+	{
+	
+		$workflowHostInfo = extractDatabaseParameters();
+
+		/* connect to workflow database */
+		$workflowDB = $GLOBALS['phpgw']->ADOdb;
+		if ($workflowDB->connect($workflowHostInfo['host'], $workflowHostInfo['user'], $workflowHostInfo['password'], 'workflow'))
+		{
+			$workflowDB->query('ALTER TABLE ONLY public.funcionario ADD COLUMN funcao CHARACTER VARYING(200)');
+			$workflowDB->query('ALTER TABLE ONLY public.funcionario ADD COLUMN data_admissao DATE');
+			$workflowDB->query('ALTER TABLE ONLY public.funcionario ADD COLUMN apelido CHARACTER VARYING(20)');
+		}
+
+		/* reconnect to the previous database */
+		$GLOBALS['phpgw']->ADOdb->connect($workflowHostInfo['host'], $workflowHostInfo['user'], $workflowHostInfo['password'], $workflowHostInfo['dbname']);
+		$GLOBALS['setup_info']['workflow']['currentver'] = '2.4.1';
+		return $GLOBALS['setup_info']['workflow']['currentver'];
+	}
 ?>
Index: /branches/2.4/workflow/setup/setup.inc.php
===================================================================
--- /branches/2.4/workflow/setup/setup.inc.php	(revision 5298)
+++ /branches/2.4/workflow/setup/setup.inc.php	(revision 6589)
@@ -13,5 +13,5 @@
 	$setup_info['workflow']['name']			= 'workflow';
 	$setup_info['workflow']['title']		= 'Workflow Management';
-	$setup_info['workflow']['version']		= '2.4.0';
+	$setup_info['workflow']['version']		= '2.4.1';
 	$setup_info['workflow']['app_order']	= 10;
 	$setup_info['workflow']['enable']		= 1;
Index: /branches/2.4/workflow/inc/class.ui_userinterface.inc.php
===================================================================
--- /branches/2.4/workflow/inc/class.ui_userinterface.inc.php	(revision 6503)
+++ /branches/2.4/workflow/inc/class.ui_userinterface.inc.php	(revision 6589)
@@ -170,5 +170,5 @@
 		}
 
-		//Verifica a permissÃ£o do usuÃ¡rio
+		//Verifica a permissão do usuário
 		$so->_checkAccess($organizationID);
 
Index: /branches/2.4/workflow/inc/class.so_orgchart.inc.php
===================================================================
--- /branches/2.4/workflow/inc/class.so_orgchart.inc.php	(revision 6507)
+++ /branches/2.4/workflow/inc/class.so_orgchart.inc.php	(revision 6589)
@@ -128,5 +128,4 @@
 		$this->acl = &$GLOBALS['ajax']->acl;
 		$this->db = &Factory::getInstance('WorkflowObjects')->getDBWorkflow()->Link_ID;
-		$this->db = &Factory::getInstance('WorkflowObjects')->getDBWorkflow()->Link_ID;
 		$this->db->SetFetchMode(ADODB_FETCH_ASSOC);
 	}
@@ -706,5 +705,5 @@
 		$supervisors = '{' . implode(', ', $areaInfo) . '}';
 
-		$query = "SELECT funcionario_id, funcionario_status_id, centro_custo_id, localidade_id, organizacao_id, area_id, cargo_id, nivel, funcionario_categoria_id, titulo, funcao, to_char(data_admissao,'DD/MM/YYYY') as data_admissao, apelido FROM funcionario WHERE ((area_id = ?) AND (organizacao_id = ?)) OR (funcionario_id = ANY (?))"; 
+		$query = "SELECT funcionario_id, funcionario_status_id, centro_custo_id, localidade_id, organizacao_id, area_id, cargo_id, nivel, funcionario_categoria_id, titulo, funcao, to_char(data_admissao,'DD/MM/YYYY') as data_admissao, apelido FROM funcionario WHERE ((area_id = ?) AND (organizacao_id = ?)) OR (funcionario_id = ANY (?))";
 		$result = $this->db->query($query, array($areaID, $organizationID, $supervisors));
 		$this->_checkError($result);
@@ -784,5 +783,5 @@
 
 		/* load employee information */
-		$query = "SELECT f.funcionario_id, f.funcionario_status_id, f.centro_custo_id, f.localidade_id, f.organizacao_id, f.area_id, f.cargo_id, f.nivel, f.funcionario_categoria_id, f.titulo, f.apelido, f.funcao, f.data_admisao, a.sigla AS area_sigla FROM funcionario f, area a WHERE (f.area_id = a.area_id) AND (f.organizacao_id = $organizationID) AND (f.funcionario_id IN (" . implode(',', array_keys($unifiedResult))  ."))";
+		$query = "SELECT f.funcionario_id, f.funcionario_status_id, f.centro_custo_id, f.localidade_id, f.organizacao_id, f.area_id, f.cargo_id, f.nivel, f.funcionario_categoria_id, f.titulo, f.apelido, f.funcao, to_char(f.data_admissao, 'DD/MM/YYYY') as data_admissao, a.sigla AS area_sigla FROM funcionario f, area a WHERE (f.area_id = a.area_id) AND (f.organizacao_id = $organizationID) AND (f.funcionario_id IN (" . implode(',', array_keys($unifiedResult))  ."))";
 		$result = $this->db->query($query);
 		$this->_checkError($result);
@@ -801,60 +800,68 @@
 	}
 
- 	
-	/** 
- 	 * Valida se o formato da data está correto.. 
- 	 * @param $date data a ser validada. 
- 	 **/ 
- 		 
- 	function validateDate($date) 
- 	{ 
- 	        $date_pattern = '/^(0[1-9]|[12][0-9]|3[01])\/(0[1-9]|1[0-2])\/[12][0-9]{3}$/'; 
- 	 
- 	        if (!preg_match($date_pattern, $date)) 
- 	                $this->endExecution("Formato inválido para data (dd/mm/aaaa)."); 
- 	} 
- 		 
+
+	/**
+	 * Valida se o formato da data está correto..
+	 * @param $date data a ser validada.
+	 **/
+
+	function validateDate($date)
+	{
+		$date_pattern = '/^(0[1-9]|[12][0-9]|3[01])\/(0[1-9]|1[0-2])\/[12][0-9]{3}$/';
+
+		if (!preg_match($date_pattern, $date))
+			$this->endExecution("Formato inválido para data (dd/mm/aaaa).");
+	}
+
 	/**
 	 * Adiciona um funcionário.
-         * @param int $employeeID O ID do funcionário. 
- 	 * @param int $organizationID O ID da organização. 
- 	 * @param int $areaID O ID da área. 
- 	 * @param int $costCenterID O ID do centro de custo. 
- 	 * @param int $localID O ID da localidade. 
- 	 * @param int $employeeStatusID O ID do status do funcionário. 
- 	 * @param int $jobTitleID O ID do cargo do funcionário. 
- 	 * @param int $level O nível do cargo do funcionário. 
- 	 * @param int $title O título do funcionário. 
- 	 * @param int $nickname O apelido do funcionário. 
- 	 * @param int $jobDesc A descrição do cargo (função). 
- 	 * @param int $admDate Data de admissão do funcionário. 
- 	 * @return bool TRUE se a ação foi concluída com êxito e FALSE caso contrário. 
- 	 * @access public 
- 	 */ 
- 	function addEmployee($employeeID, $organizationID, $areaID, $costCenterID, $localID, $employeeStatusID, $jobTitleID, $level, $employeeCategoryID, $title, $nickname, $jobDesc, $admDate) 
- 	{ 
- 	        $this->_checkAccess($organizationID); 
- 	        $this->validateDate($admDate); 
- 		 
- 	        $query = 'SELECT area.sigla FROM funcionario, area WHERE (funcionario.area_id = area.area_id) AND (funcionario.funcionario_id = ?)'; 
- 	        if (($row = $this->db->query($query, $employeeID)->fetchRow())) 
- 	        { 
- 	                $errors = array( 
- 	                        "O funcionário \"" . Factory::getInstance('WorkflowLDAP')->getName($employeeID) . "\" já pertença à área \"{$row['sigla']}\".", 
- 	                        '-----------------', 
- 	                        'Caso você queira colocá-lo na área selecionada, siga o procedimento: faça uma busca por seu nome, clique para editá-lo e, troque pela área desejada.' 
- 	                ); 
- 	                $this->endExecution($errors); 
- 	        } 
- 	
- 	        $query = "INSERT INTO funcionario(funcionario_id, organizacao_id, area_id, centro_custo_id, localidade_id, funcionario_status_id, cargo_id, nivel, funcionario_categoria_id, titulo, apelido, funcao, data_admissao) VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)"; 
- 	        $result = $this->db->query($query, array($employeeID, $organizationID, $areaID, $costCenterID, $localID, $employeeStatusID, $jobTitleID, $level, $employeeCategoryID, $title, $nickname, $jobDesc, $admDate)); 
- 	        $this->_checkError($result); 
- 	 
- 	        return (($result === false) ? false : true); 
- 	} 
- 		 
- 	/** 
- 	 * Atualiza o funcionário. 
+	 * @param int $employeeID O ID do funcionário.
+	 * @param int $organizationID O ID da organização.
+	 * @param int $areaID O ID da área.
+	 * @param int $costCenterID O ID do centro de custo.
+	 * @param int $localID O ID da localidade.
+	 * @param int $employeeStatusID O ID do status do funcionário.
+	 * @param int $jobTitleID O ID do cargo do funcionário.
+	 * @param int $level O nível do cargo do funcionário.
+	 * @param int $title O título do funcionário.
+ 	 * @param int $nickname O apelido do funcionário.
+ 	 * @param int $jobDesc A descrição do cargo (função).
+ 	 * @param int $admDate Data de admissão do funcionário.
+	 * @return bool TRUE se a ação foi concluída com êxito e FALSE caso contrário.
+	 * @access public
+	 */
+	function addEmployee($employeeID, $organizationID, $areaID, $costCenterID, $localID, $employeeStatusID, $jobTitleID, $level, $employeeCategoryID, $title, $nickname, $jobDesc, $admDate)
+	{
+		$this->_checkAccess($organizationID);
+		if ($admDate!='')
+		{
+			$this->validateDate($admDate);
+			$admission_date = implode('-', array_reverse(explode('/', $admDate)));
+		}
+		else
+		{
+			$admission_date=NULL;
+		}
+
+		$query = 'SELECT area.sigla FROM funcionario, area WHERE (funcionario.area_id = area.area_id) AND (funcionario.funcionario_id = ?)';
+		if (($row = $this->db->query($query, $employeeID)->fetchRow()))
+		{
+			$errors = array(
+				"O funcionário \"" . Factory::getInstance('WorkflowLDAP')->getName($employeeID) . "\" já pertença à área \"{$row['sigla']}\".",
+				'-----------------',
+				'Caso você queira colocá-lo na área selecionada, siga o procedimento: faça uma busca por seu nome, clique para editá-lo e, troque pela área desejada.'
+			);
+			$this->endExecution($errors);
+		}
+
+		$query = "INSERT INTO funcionario(funcionario_id, organizacao_id, area_id, centro_custo_id, localidade_id, funcionario_status_id, cargo_id, nivel, funcionario_categoria_id, titulo, apelido, funcao, data_admissao) VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
+		$result = $this->db->query($query, array($employeeID, $organizationID, $areaID, $costCenterID, $localID, $employeeStatusID, $jobTitleID, $level, $employeeCategoryID, $title, $nickname, $jobDesc, $admission_date));
+		$this->_checkError($result);
+
+		return (($result === false) ? false : true);
+	}
+
+	/**
+	 * Atualiza o funcionário.
 	 * @param int $employeeID O ID do funcionário.
 	 * @param int $organizationID O ID da organização.
@@ -866,20 +873,30 @@
 	 * @param int $level O nível do cargo do funcionário.
 	 * @param int $employeeCategoryID O ID da categoria do funcionário.
-	 * @param int $title O título do funcionário. 
- 	 * @param int $nickname O apelido do funcionário. 
- 	 * @param int $jobDesc A descrição do cargo (função). 
- 	 * @param int $admDate Data de admissão do funcionário. 
- 	 * @return bool TRUE se a ação foi concluída com êxito e FALSE caso contrário. 
- 	 * @access public 
- 	 */ 
- 	function updateEmployee($employeeID, $organizationID, $areaID, $costCenterID, $localID, $employeeStatusID, $jobTitleID, $level, $employeeCategoryID, $title, $nickname, $jobDesc, $admDate) 
- 	{ 
- 	        $this->_checkAccess($organizationID); 
- 	        $this->validateDate($admDate); 
- 		                 
- 	        $query = "UPDATE funcionario SET area_id = ?, centro_custo_id = ?, localidade_id = ?, funcionario_status_id = ?, cargo_id = ?, nivel = ?, funcionario_categoria_id = ?, titulo = ?, apelido = ?, funcao = ?, data_admissao = ? WHERE (funcionario_id = ?) AND (organizacao_id = ?)"; 
- 	        $result = $this->db->query($query, array($areaID, $costCenterID, $localID, $employeeStatusID, $jobTitleID, $level, $employeeCategoryID, $title,$nickname, $jobDesc, $admDate, $employeeID, $organizationID)); 
-		$this->_checkError($result);
-
+	 * @param int $title O título do funcionário.
+ 	 * @param int $nickname O apelido do funcionário.
+ 	 * @param int $jobDesc A descrição do cargo (função).
+ 	 * @param int $admDate Data de admissão do funcionário.
+	 * @return bool TRUE se a ação foi concluída com êxito e FALSE caso contrário.
+	 * @access public
+	 */
+	function updateEmployee($employeeID, $organizationID, $areaID, $costCenterID, $localID, $employeeStatusID, $jobTitleID, $level, $employeeCategoryID, $title, $nickname, $jobDesc, $admDate)
+	{
+		$this->_checkAccess($organizationID);
+		if ($admDate!='')
+		{
+			$this->validateDate($admDate);
+			$admission_date = implode('-', array_reverse(explode('/', $admDate)));
+		}
+		else
+		{
+			$admission_date=NULL;
+		}
+
+		$query = "UPDATE funcionario SET area_id = ?, centro_custo_id = ?, localidade_id = ?, funcionario_status_id = ?, cargo_id = ?, nivel = ?, funcionario_categoria_id = ?, titulo = ?, apelido = ?, funcao = ?, data_admissao =? WHERE (funcionario_id = ?) AND (organizacao_id = ?)";
+			
+		$result = $this->db->query($query, array($areaID, $costCenterID, $localID, $employeeStatusID, $jobTitleID, $level, $employeeCategoryID, $title,$nickname, $jobDesc, $admission_date, $employeeID, $organizationID));
+		
+		$this->_checkError($result);
+		
 		return (($result === false) ? false : true);
 	}
Index: /branches/2.4/workflow/inc/class.so_userinterface.inc.php
===================================================================
--- /branches/2.4/workflow/inc/class.so_userinterface.inc.php	(revision 6503)
+++ /branches/2.4/workflow/inc/class.so_userinterface.inc.php	(revision 6589)
@@ -14,5 +14,5 @@
 	var $db;
 	/**
-	 * @var bool True se o usuÃ¡rio for administrador do expresso.
+	 * @var bool True se o usuário for administrador do expresso.
 	 * @access private
 	 */
@@ -20,5 +20,5 @@
 
 	/**
-	 * @var int ID do usuÃ¡rio logado no Expresso
+	 * @var int ID do usuário logado no Expresso
 	 * @access private
 	 */
@@ -32,5 +32,5 @@
 	
 	/**
-	 * @var bool indicando se o usuÃ¡rio possui ou nÃ£o acesso aos dados restritos.
+	 * @var bool indicando se o usuário possui ou não acesso aos dados restritos.
 	 * @access private
 	 */
@@ -248,6 +248,6 @@
 
 	/**
-	 * Checa se o usuÃ¡rio possui permissÃ£o para visualizar informaÃ§Ãµes restritas.
-	 * @param int $organizationID O ID da organizaÃ§Ã£o do Orgranograma.
+	 * Checa se o usuário possui permissão para visualizar informações restritas.
+	 * @param int $organizationID O ID da organização do Orgranograma.
 	 * @return void
 	 * @access public
@@ -289,5 +289,5 @@
 
 		/* load the employees from the area */
-		$query = "SELECT f.funcionario_id, f.organizacao_id, f.area_id, COALESCE(f.funcionario_categoria_id, 0) AS funcionario_categoria_id FROM funcionario f, funcionario_status s WHERE ((f.area_id = ?) OR (f.funcionario_id = ANY (?))) AND (f.funcionario_status_id = s.funcionario_status_id) AND (s.exibir = ?)";
+		$query = "SELECT f.funcionario_id, f.organizacao_id, f.area_id, f.funcao, to_char(f.data_admissao,'DD/MM/YYYY') as data_admissao, COALESCE(f.funcionario_categoria_id, 0) AS funcionario_categoria_id FROM funcionario f, funcionario_status s WHERE ((f.area_id = ?) OR (f.funcionario_id = ANY (?))) AND (f.funcionario_status_id = s.funcionario_status_id) AND (s.exibir = ?)";
 		$result = $this->db->query($query, array($areaID, $supervisors, 'S'));
 
@@ -301,5 +301,10 @@
 			for ($j = 0; $j < $result->_numOfFields; $j++)
 				unset($employees[$i][$j]);
-			
+			if (!$this->authorized || !isset($employees[$i]['funcao']))
+				$employees[$i]['funcao'] = '';
+			else
+				$employees[$i]['funcao'] = utf8_encode($employees[$i]['funcao']);	
+			if (!$this->authorized || !isset($employees[$i]['data_admissao']))
+				$employees[$i]['data_admissao'] = '';
 			$employees[$i]['cn'] = '';
 			$employees[$i]['telephoneNumber'] = '';
@@ -330,5 +335,5 @@
 			$employees[$i]['cargo'] = utf8_encode($cargo);	
 			
-			/*busca o vÃ­nculo do funcionario*/
+			/*busca o vínculo do funcionario*/
 			$vinculo = '';
 			if ($this->authorized && !empty($employeeInfo['funcionario_categoria_id']))
Index: /branches/2.4/workflow/js/orgchart/organization.js
===================================================================
--- /branches/2.4/workflow/js/orgchart/organization.js	(revision 6507)
+++ /branches/2.4/workflow/js/orgchart/organization.js	(revision 6589)
@@ -703,11 +703,11 @@
 	content += '<a href="javascript:void(0)" onclick="openParticipants(\'funcionario_id\', \'uid=1&hidegroups=1\');" id="addEmployeeLink"><img border="0" width="16" height="16" src="workflow/templateFile.php?file=images/add_user.png" /></a>';
 	content += '</td></tr>';
-	content += '<tr><td><label for="apelido">Apelido</label></td><td><input type="text" size="20" maxlength="20" name="apelido" id="apelido"/></td></tr>';
+	content += '<tr><td><label for="apelido">Apelido</label></td><td><input type="text" size="20" maxlength="20" name="apelido" id="apelido" value=""/></td></tr>';
 	content += '<tr><td><label for="funcionario_status_id">Status</label></td><td id="comboStatus"><i>carregando</i></td></tr>';
 	content += '<tr><td><label for="funcionario_categoria_id">Categoria</label></td><td id="comboFuncionarioCategoria"><i>carregando</i></td></tr>';
 	content += '<tr><td><label for="cargo_id">Cargo</label></td><td id="comboCargo"><i>carregando</i></td></tr>';
-	content += '<tr><td><label for="funcao">FunÃ§Ã£o</label></td><td><input type="text" size="50" maxlength="200" name="funcao" id="funcao"/></td></tr>';
-	content += '<tr><td><label for="data_admissao">Data de admissÃ£o</label></td><td><input type="text" name="data_admissao" id="data_admissao" size="15" onkeypress="return formatDateField(event, this);" /></td></tr>';
-	content += '<tr><td><label for="titulo">T&iacute;tulo</label></td><td><input type="text" size="30" name="titulo" id="titulo"/></td></tr>';
+	content += '<tr><td><label for="funcao">Função</label></td><td><input type="text" size="50" maxlength="200" name="funcao" id="funcao" value=""/></td></tr>';
+	content += '<tr><td><label for="data_admissao">Data de admissão</label></td><td><input type="text" name="data_admissao" id="data_admissao" value="" size="15" onkeypress="return formatDateField(event, this);" /></td></tr>';
+	content += '<tr><td><label for="titulo">T&iacute;tulo</label></td><td><input type="text" size="30" name="titulo" id="titulo" value=""/></td></tr>';
 
 	content += '<tr><td><label for="nivel">Nível</label></td><td><input type="text" size="3" name="nivel" id="nivel"/></td></tr>';
Index: /branches/2.4/workflow/js/adminaccess/main.js
===================================================================
--- /branches/2.4/workflow/js/adminaccess/main.js	(revision 6503)
+++ /branches/2.4/workflow/js/adminaccess/main.js	(revision 6589)
@@ -34,5 +34,5 @@
 permissionListORG[0]['name'] = "Administrar Organograma";
 permissionListORG[0]['value'] = 0;
-permissionListORG[1]['name'] = "Visualizar InformaÃ§Ãµes Restritas";
+permissionListORG[1]['name'] = "Visualizar Informações Restritas";
 permissionListORG[1]['value'] = 1;
 

Index: /branches/2.4/workflow/js/userinterface/orgchartPrint.js
===================================================================
--- /branches/2.4/workflow/js/userinterface/orgchartPrint.js	(revision 6503)
+++ /branches/2.4/workflow/js/userinterface/orgchartPrint.js	(revision 6589)
@@ -88,10 +88,10 @@
 	if (showUserPhoto){
 		var content = '<img src="workflow/showUserPicture.php?userID=' + areas[area_id].employees[user_id].funcionario_id + '"/>';
-		element.append($('<td>' + content + '</td>').css('width', '8%'));
+		element.append($('<td valign="top">' + content + '</td>').css('width', '8%'));
 	}
 
 	/* name: first column */
 	element.append(
-				$('<td></td>')
+				$('<td valign="top"></td>')
 					.append(
 						$('<span></span>')
@@ -99,5 +99,5 @@
 							.append(areas[area_id].employees[user_id].cn)
 						)
-							.css('width', '30%')
+							.css('width', '23.5%')
 			);
 
@@ -106,32 +106,44 @@
 		element.append(
 						$('<td>' + areas[area_id].sigla + '</td>')
-							.css('width', '10%')
 					);
 
 	/* login: show uid attribute */
 	element.append(
-					$('<td>' + areas[area_id].employees[user_id].uid + '</td>')
-						.css('width', '15%') 
- 	                                ) 
-
-
+					$('<td valign="top">' + areas[area_id].employees[user_id].uid + '</td>')
+						.css('width', '11%')
+					)
+					
+	
 	/* telephone: last column */
 	element.append(
-					$('<td>' + areas[area_id].employees[user_id].telephoneNumber + '</td>')
-						.css('width', '15%') 
- 	                                ) 
- 		                                         
- 	/* VÃÂ­nculo: show cargo vÃÂ­nculo */ 
- 	element.append( 
- 	                                $('<td>' + areas[area_id].employees[user_id].vinculo + '</td>') 
- 	                                        .css('width', '15%') 
- 	                                ) 
- 		 
- 	/* Cargo: show cargo attribute */ 
- 	element.append( 
- 	                                $('<td>' + areas[area_id].employees[user_id].cargo + '</td>') 
- 	                                        .css('width', '15%') 
- 	                                ) 
- 		 
+					$('<td valign="top">' + areas[area_id].employees[user_id].telephoneNumber + '</td>')
+						.css('width', '9.75%')
+					)
+					
+	/* VÃ­nculo: show cargo vÃ­nculo */
+	element.append(
+					$('<td valign="top">' + areas[area_id].employees[user_id].vinculo + '</td>')
+						.css('width', '9%')
+					)
+
+	/* Cargo: show cargo attribute */
+	element.append(
+					$('<td valign="top">' + areas[area_id].employees[user_id].cargo + '</td>')
+						.css('width', '12.5%')
+					)
+					
+		/* data_admissao: show data_admissao attribute */
+	element.append(
+					$('<td valign="top">' + areas[area_id].employees[user_id].data_admissao + '</td>')
+						.css('width', '6.75%')
+					)
+					
+	/* Funcao: show funcao attribute */
+	element.append(
+				$('<td valign="top"> ' + areas[area_id].employees[user_id].funcao + ' </td>')
+						.css('width', '26%')
+					)
+
+
 				.addClass('employees');
 